package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.30.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.30.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````D"D```````!``````````%#!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!`````````````````````````````````````@;````````"!L`````````
M$`````````$````%`````"``````````(``````````@````````_4``````
M``#]0``````````0`````````0````0`````<`````````!P`````````'``
M```````H10```````"A%`````````!`````````!````!@```+B[````````
MN,L```````"XRP```````&@$````````$!4`````````$`````````(````&
M````R+L```````#(RP```````,C+````````$`(````````0`@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M``"`K0```````("M````````@*T````````,`0````````P!````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````N+L```````"XRP```````+C+````
M````2`0```````!(!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``@``P`0````#````````
M``0````4`````P```$=.50#:XHJ(__$=BO#'D:+\%,!:>+00Y@0````0````
M`0```$=.50```````P````(``````````````!$```!"````!`````@````@
M'!``!4`$AB@"0`20A@"$@@D`($D@!`BXHA%%N@`""@````!"````10```$@`
M``!)````4````%$```!3````5P```%@```!:````6P```%X```!@````8@``
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP$+ZUX?"Y3\LNN.2?/NA;&!K"4/69J_,9L6YG$`X\HL<Q(D%D$)%U>R)
M!W#3#13BGC)BV^W;S>.>%8PES`PZEPM6I)N6I]VC:WZIG)O19<YMX*<""FL:
MGE`*BA!7H^#[20````````````````````````````````````#C`0``$@``
M```````````````````````,`0``$@````````````````````````"3````
M$@````````````````````````"6`@``$@````````````````````````#=
M`0``$@````````````````````````"3`0``$@``````````````````````
M``!1`@``$@````````````````````````"!`@``$@``````````````````
M```````B`0``$@`````````````````````````M````(```````````````
M```````````5`@``$@`````````````````````````X`P``$@``````````
M``````````````#^`0``$@`````````````````````````:`@``$@``````
M``````````````````"J`0``$@`````````````````````````<`P``$@``
M``````````````````````!3`0``$@````````````````````````"T````
M$@````````````````````````!#`0``$@`````````````````````````\
M`@``$@````````````````````````![`@``$@``````````````````````
M```U`0``$@````````````````````````!8`@``$@``````````````````
M``````#:`P``$@`````````````````````````1````(```````````````
M``````````"Q`0``$@`````````````````````````1`0``$@``````````
M``````````````!M`@``$@`````````````````````````\````(```````
M``````````````````"O`@``$@````````````````````````!6````$@``
M``````````````````````"#`0``$@````````````````````````!S````
M$@````````````````````````#P````$@````````````````````````"$
M````$@````````````````````````#W`0``$@``````````````````````
M``!T`@``$@````````````````````````#4````$@``````````````````
M``````#/`@``$@````````````````````````!U`0``$@``````````````
M```````````&`P``$@````````````````````````#8`@``$@``````````
M``````````````"D`@``$@````````````````````````!G`0``$@``````
M``````````````````#,`0``$@````````````````````````!?`@``$@``
M```````````````````````6`0``$@`````````````````````````K`@``
M$@`````````````````````````5`P``$@````````````````````````!F
M`@``$@````````````````````````#(`@``$@``````````````````````
M``"?````$@````````````````````````"W`@``$@``````````````````
M``````">`0``$@`````````````````````````#`@``$@``````````````
M```````````B`@``$@````````````````````````#X`@``$@``````````
M```````````````.`P``$@````````````````````````!)`@``$@``````
M``````````````````!<`0``$@````````````````````````!D````$@``
M``````````````````````"/`@``$@````````````````````````#?`@``
M$@````````````````````````!#`@``$@````````````````````````#"
M````$@````````````````````````#C`P``$@`0``!%````````=P``````
M``!(!```$@`0`#`Y````````Y0<````````I`P``$@`0`(`G````````#`(`
M``````!*`P``$@`0`(`R````````"0````````!X`P``$@`0`"!!````````
MV0,```````!N!```$@`0`)`R`````````@(````````N!```$``:`"#0````
M``````````````!;`P``$@`0`*`T````````)0````````".`P``$@`0`)`W
M````````?`````````#O`P``$0`2``!P````````!``````````+!```$@`0
M`+!<````````KP$````````6!```$@`0`!`Q````````-`````````!#!```
M$``:`,C@``````````````````!<!```$@`0`$`X````````Y@````````#^
M`P``$``9``#0``````````````````"R`P``$@`0`-`T````````W```````
M```N`P``$0`:`$#0````````"`````````#!`@``$0`:`&#0````````"```
M```````O`P``(0`:`$#0````````"`````````!5!```$``9`"#0````````
M``````````![!```$0`9`!C0````````"`````````!H`P``$@`0`-!@````
M````!0`````````$!```$@`0`)`I````````+P`````````>!```$@`0`&!@
M````````90`````````Z!```$@`0`%!<````````6```````````!```(``9
M``#0```````````````````!`0``$0`:`"#0````````!``````````P`P``
M(0`:`$#0````````"`````````#(`P``$@`0`!`X````````(0````````#I
M`@``(@````````````````````````"<`P``$@`0`*`Q````````V```````
M``"^`P``$@`0`&!>````````^P$```````#C````$0`:`(#0`````````0``
M``````"%!```$@`0`+`U````````U@$`````````;&EB<&5R;"YS;RXU+C,P
M`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E
M<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!0
M97)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R
M;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A
M9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)P=&AR96%D+G-O+C``7U]E<G)N
M;U]L;V-A=&EO;@!C;&]S90!P=&AR96%D7V=E='-P96-I9FEC`&]P96XV-`!R
M96%D`&QS965K-C0`;&EB8RYS;RXV`&5X:70`<W1R;F-M<`!C;&]S961I<@!?
M7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&UE;6-H<@!G
M971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R<W1R`')M9&ER`%]?9G!R
M:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L>'-T870V-`!O<&5N
M9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L:6YK`'-T<F-H<@!R
M96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F7V-H:P!M96UM;W9E
M`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]?
M<F5G:7-T97)?871F;W)K`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE
M`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N
M=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA
M7V9I;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN
M:70`7U]L:6)C7V-S=5]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`
M<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN
M9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C$T`$=,24)#
M7S(N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C(N-0!'3$E"0U\R+C,N-``````"
M```````#``(````$``,```````0`!0`"``0`!``$``````````0`!`````0`
M!```````!``$````!````````````````@`$````!`````0`!``$`````@`$
M````!@`$``0`!`````0````"``0``P`$``0```````<`!``$`````0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`$``0`!``!``$``0`!``$``0`!
M````!``!``0``0`!`````0```````0`%``L"```0````8````)21E@8```<`
MD@0``!`````4:6D-```&`)T$```0````<AEI"0``!0"G!```$````'4::0D`
M``0`LP0``!````!T&6D)```#`+\$`````````0`!`+P!```0`````````'4:
M:0D```(`LP0```````"XRP````````@`````````<"H```````#`RP``````
M``@`````````,"H````````(T`````````@`````````"-`````````8T```
M``````@`````````X'(```````#`SP````````8````)``````````````#(
MSP````````8````*``````````````#0SP````````8````0````````````
M``#8SP````````8````9``````````````#@SP````````8````=````````
M``````#HSP````````8```!?``````````````#PSP````````8````@````
M``````````#XSP````````8````A```````````````@T`````````4```!<
M``````````````!`T`````````4```!2``````````````!@T`````````4`
M``!3``````````````"`T`````````4```!B``````````````#PS0``````
M``<````!``````````````#XS0````````<````"````````````````S@``
M``````<````#```````````````(S@````````<````$```````````````0
MS@````````<````%```````````````8S@````````<````&````````````
M```@S@````````<````'```````````````HS@````````<````(````````
M```````PS@````````<````+```````````````XS@````````<````,````
M``````````!`S@````````<````-``````````````!(S@````````<````.
M``````````````!0S@````````<````/``````````````!8S@````````<`
M```1``````````````!@S@````````<````2``````````````!HS@``````
M``<````3``````````````!PS@````````<````4``````````````!XS@``
M``````<````5``````````````"`S@````````<````6``````````````"(
MS@````````<````7``````````````"0S@````````<````8````````````
M``"8S@````````<````:``````````````"@S@````````<````;````````
M``````"HS@````````<````<``````````````"PS@````````<````>````
M``````````"XS@````````<````?``````````````#`S@````````<````B
M``````````````#(S@````````<````C``````````````#0S@````````<`
M```D``````````````#8S@````````<````E``````````````#@S@``````
M``<````F``````````````#HS@````````<````G``````````````#PS@``
M``````<````H``````````````#XS@````````<````I````````````````
MSP````````<````J```````````````(SP````````<````K````````````
M```0SP````````<````L```````````````8SP````````<````M````````
M```````@SP````````<````N```````````````HSP````````<````O````
M```````````PSP````````<````P```````````````XSP````````<````Q
M``````````````!`SP````````<````R``````````````!(SP````````<`
M```S``````````````!0SP````````<````T``````````````!8SP``````
M``<````U``````````````!@SP````````<````V``````````````!HSP``
M``````<````W``````````````!PSP````````<````X``````````````!X
MSP````````<````Y``````````````"`SP````````<````Z````````````
M``"(SP````````<````[``````````````"0SP````````<````\````````
M``````"8SP````````<````]``````````````"@SP````````<````^````
M``````````"HSP````````<````_``````````````"PSP````````<```!`
M``````````````"XSP````````<```!!````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;FO``!(A<!T`O_02(/$",,``````/\UNJT``/+_);NM
M```/'P#S#Q[Z:`````#RZ>'___^0\P\>^F@!````\NG1____D/,/'OIH`@``
M`/+IP?___Y#S#Q[Z:`,```#RZ;'___^0\P\>^F@$````\NFA____D/,/'OIH
M!0```/+ID?___Y#S#Q[Z:`8```#RZ8'___^0\P\>^F@'````\NEQ____D/,/
M'OIH"````/+I8?___Y#S#Q[Z:`D```#RZ5'___^0\P\>^F@*````\NE!____
MD/,/'OIH"P```/+I,?___Y#S#Q[Z:`P```#RZ2'___^0\P\>^F@-````\ND1
M____D/,/'OIH#@```/+I`?___Y#S#Q[Z:`\```#RZ?'^__^0\P\>^F@0````
M\NGA_O__D/,/'OIH$0```/+IT?[__Y#S#Q[Z:!(```#RZ<'^__^0\P\>^F@3
M````\NFQ_O__D/,/'OIH%````/+IH?[__Y#S#Q[Z:!4```#RZ9'^__^0\P\>
M^F@6````\NF!_O__D/,/'OIH%P```/+I<?[__Y#S#Q[Z:!@```#RZ6'^__^0
M\P\>^F@9````\NE1_O__D/,/'OIH&@```/+I0?[__Y#S#Q[Z:!L```#RZ3'^
M__^0\P\>^F@<````\NDA_O__D/,/'OIH'0```/+I$?[__Y#S#Q[Z:!X```#R
MZ0'^__^0\P\>^F@?````\NGQ_?__D/,/'OIH(````/+IX?W__Y#S#Q[Z:"$`
M``#RZ=']__^0\P\>^F@B````\NG!_?__D/,/'OIH(P```/+IL?W__Y#S#Q[Z
M:"0```#RZ:']__^0\P\>^F@E````\NF1_?__D/,/'OIH)@```/+I@?W__Y#S
M#Q[Z:"<```#RZ7']__^0\P\>^F@H````\NEA_?__D/,/'OIH*0```/+I4?W_
M_Y#S#Q[Z:"H```#RZ4']__^0\P\>^F@K````\NDQ_?__D/,/'OIH+````/+I
M(?W__Y#S#Q[Z:"T```#RZ1']__^0\P\>^F@N````\ND!_?__D/,/'OIH+P``
M`/+I\?S__Y#S#Q[Z:#````#RZ>'\__^0\P\>^F@Q````\NG1_/__D/,/'OIH
M,@```/+IP?S__Y#S#Q[Z:#,```#RZ;'\__^0\P\>^F@T````\NFA_/__D/,/
M'OIH-0```/+ID?S__Y#S#Q[Z:#8```#RZ8'\__^0\P\>^F@W````\NEQ_/__
MD/,/'OIH.````/+I8?S__Y#S#Q[Z:#D```#RZ5'\__^0\P\>^O+_)0VL```/
M'T0``/,/'OKR_R4%J@``#Q]$``#S#Q[Z\O\E_:D```\?1```\P\>^O+_)?6I
M```/'T0``/,/'OKR_R7MJ0``#Q]$``#S#Q[Z\O\EY:D```\?1```\P\>^O+_
M)=VI```/'T0``/,/'OKR_R75J0``#Q]$``#S#Q[Z\O\ES:D```\?1```\P\>
M^O+_)<6I```/'T0``/,/'OKR_R6]J0``#Q]$``#S#Q[Z\O\EM:D```\?1```
M\P\>^O+_):VI```/'T0``/,/'OKR_R6EJ0``#Q]$``#S#Q[Z\O\EG:D```\?
M1```\P\>^O+_)96I```/'T0``/,/'OKR_R6-J0``#Q]$``#S#Q[Z\O\EA:D`
M``\?1```\P\>^O+_)7VI```/'T0``/,/'OKR_R5UJ0``#Q]$``#S#Q[Z\O\E
M;:D```\?1```\P\>^O+_)66I```/'T0``/,/'OKR_R5=J0``#Q]$``#S#Q[Z
M\O\E5:D```\?1```\P\>^O+_)4VI```/'T0``/,/'OKR_R5%J0``#Q]$``#S
M#Q[Z\O\E/:D```\?1```\P\>^O+_)36I```/'T0``/,/'OKR_R4MJ0``#Q]$
M``#S#Q[Z\O\E):D```\?1```\P\>^O+_)1VI```/'T0``/,/'OKR_R45J0``
M#Q]$``#S#Q[Z\O\E#:D```\?1```\P\>^O+_)06I```/'T0``/,/'OKR_R7]
MJ```#Q]$``#S#Q[Z\O\E]:@```\?1```\P\>^O+_)>VH```/'T0``/,/'OKR
M_R7EJ```#Q]$``#S#Q[Z\O\EW:@```\?1```\P\>^O+_)=6H```/'T0``/,/
M'OKR_R7-J```#Q]$``#S#Q[Z\O\EQ:@```\?1```\P\>^O+_);VH```/'T0`
M`/,/'OKR_R6UJ```#Q]$``#S#Q[Z\O\EK:@```\?1```\P\>^O+_):6H```/
M'T0``/,/'OKR_R6=J```#Q]$``#S#Q[Z\O\EE:@```\?1```\P\>^O+_)8VH
M```/'T0``/,/'OKR_R6%J```#Q]$``#S#Q[Z\O\E?:@```\?1```\P\>^O+_
M)76H```/'T0``/,/'OKR_R5MJ```#Q]$``#S#Q[Z\O\E9:@```\?1```\P\>
M^O+_)5VH```/'T0``/,/'OKR_R55J```#Q]$``#S#Q[Z\O\E3:@```\?1```
M\P\>^O+_)46H```/'T0``/,/'OKR_R4]J```#Q]$``#S#Q[Z05152(/L.(E\
M)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````2(E$)"@QP.AS
M____2(LU_*<``$B+/2VH``!(B?+H#3D``(`]IJ@```!U+^A/_?__2(D%V+@`
M`$B)QTB%P`^$C@$``.B7_?__BSTAJ```Z-S[___&@-$)````BST/J```Z,K[
M__^+/02H``"`B#H$```"Z+C[__^`B#H$```!BT0D'(UX!4AC_TC!YP/H?O[_
M_TR+3"00BU0D',<%6[@```0```!(B<%(B05)N```28L!2(D!2(T%9DD``$B)
M00A(BP6AIP``2(E!$$B-!5-)``!(B4$8@_H!?BU$C4+^O@$```!)@\`"#Q^$
M``````!)BP3QC7X$2(/&`4AC_TB)1/GX23GP=>B-0@1%,<"#P@-(BSWXMP``
M2)A(C35_"```2,=$P?@`````Z%'[__]!B<2%P'132(L]T[<``$B-;"0DZ"G]
M__\QP$B)[DB-/:%'``#H>`$``$B%P'0]2(L]K+<``.C7^O__Z%+\__](BT0D
M*&1(,P0E*````'5/2(/$.$2)X%U!7,-(BSV`MP``Z&O[__]!B<3KG$B+/6>W
M``!(A?]T!^BE&P``Z[!(C3WU1@``2(GNZ!0!``!(B05%MP``2(G'2(7`=)+K
MV>C>_/__OP$```#HU/K__P\?0`#S#Q[Z,>U)B=%>2(GB2(/D\%!43(T%)C<`
M`$B-#:\V``!(C3W(_?___Q42I@``])!(C3U9I@``2(T%4J8``$@Y^'052(L%
M_J4``$B%P'0)_^`/'X``````PP\?@`````!(C3TII@``2(TU(J8``$@I_DB)
M\$C![C](P?@#2`'&2-'^=!1(BP7%I0``2(7`=`C_X&8/'T0``,,/'X``````
M\P\>^H`]1J8```!U*U5(@SVBI0```$B)Y70,2(L]MJ4``.AY^?__Z&3____&
M!1ZF```!7<,/'P###Q^``````/,/'OKI=____P\?@`````!!5T%6055!5%53
M2(/L"$B%_P^$L0```$R+-:*E``!-A?8/A*$````/M@=)B?](B?6$P'0$/#UU
M6$4Q[4V+)DV%Y'0S36/M3(GS#Q^``````$R)ZDR)_DR)Y^BR^?__A<!U!T.`
M/"P]=$=,BV,(2(/#"$V%Y'7:2(/$"$R)X%M=05Q!74%>05_##Q^$``````!)
MB?U!#[9%`4F#Q0&$P'0$/#UU[T4I_>N2#Q^``````$PI\T^-9"P!2,'[`XE=
M`.NU#Q^``````$4QY.NI#Q\`55-(B?M(@^P89$B+!"4H````2(E$)`@QP$B-
M;"0$9I`QP$B)[DB)W^@#____2(7`=#9(8U0D!$B+!;*D``!(C0302(M0"$B)
M$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(BT0D"&1(,P0E*```
M`'4'2(/$&%M=P^B,^O__9F8N#Q^$``````"005=!5D%505152(GU4TB)^TB#
M["AD2(L$)2@```!(B40D&#'`,<"`/CT/E,!(`<5(B>_H.?G__TB-="042(G?
M28G$,<#H5_[__TB%P`^$#@$``$B)QTF)Q>@3^?__3#G@#X/:````3&-T)!1)
MP>8##[8#A,`/A*X!```\/0^$I@$``$B)V`\?``^V4`%(@\`!A-)T!8#Z/77O
M2"G82)A*C7P@`DP#-;:C``#H$?C__TF)!DB%P`^$A@$``$B+!9ZC``!(8U0D
M%$B-2P%(BQ30#[8#B`(\/70=A,!U".L79I`\/701#[8!2(/"`4B#P0&(`H3`
M=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O,<!(BUPD&&1(,QPE*```
M``^%%0$``$B#Q"A;74%<05U!7D%?PV8N#Q^$```````QP&8/'T0```^V5`4`
M08A4!0!(@\`!A-)U[NNU#Q]``$R+/?FB``!)@S\`#X2^````3(GX13'M9@\?
MA```````2(/`"$2)ZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP4?LP``A<!U6\<%
M$;,```$```!(B??H"??__TB%P`^$@0```$UCQ4R)_DB)QTZ--,4`````3(E$
M)`A,B?+H,OC__TR+1"0(2(D%=J(``$B)P4K'1,$(`````$2);"04Z6_^__],
MB?_H*/G__TB)!5&B``!(B<%(A<!T*DUCQ4Z--,4`````Z\D/'T``,<#I;_[_
M_[X0````13'MZ5_____H/_C__X/(_^G*_O__#Q^``````$%6055!5%532('L
MH````&1(BP0E*````$B)A"28````,<!(A?]T"(`_`$B)_74Q2(N$))@```!D
M2#,$)2@````/A1$!``!(@<2@````6UU!7$%=05[#9BX/'X0``````.C+]O__
M28G$2(7`=,)(B>-,B>?HJ/C__TB%P`^$IP```&:#>!,N3(UP$W3D9H%X$RXN
M#X2H````2(GOZ(#V__],B?=)B<7H=?;__T&-?`4"2&/_Z+CU__]-B?%)B>B^
M`0```$F)Q4B)QS'`2,?"_____TB-#?Y```#HXO?__[\!````2(G:3(GNZ)+W
M__],B>^#^/]T$(M$)!@E`/```#T`0```=$KHI?7__TR)[^C]]?__3(GGZ`7X
M__](A<`/A5W___\/'T``3(GGZ(#W__](B>_HB/7__^GR_O__#Q\`08!^`@`/
MA"7____I2/___^BK_O__Z[3HU/;__P\?0`!52(G^2(G]OP$```!(@>R@````
M9$B+!"4H````2(F$))@````QP$B)XNA2]O__A<!U-HM4)!B!X@#P``"!^@!`
M``!T"('Z`*```'4>O@(```!(B>_H%_?__X7`#Y3`#[;`ZP</'T0``#'`2(N,
M))@```!D2#,,)2@```!U"4B!Q*````!=P^A%]O__#Q]$``!!5T%6055!5%5(
M@>P`$```2(,,)`!(@^P0NO\/``!D2(L$)2@```!(B80D"!```#'`28GE2(G]
M28GT2(T]K#\``$R)[NAG]?__A<!^>XU0_T2+/:F?``!,8_)"@#PT`'5?A=)T
M:DR)\KXO````3(GOZ*OS__](A<!T542)_^@^\___3(GQ3(GJ2(GN2(G'Z`WU
M__](BX0D"!```&1(,P0E*````'5!2('$$!```%U!7$%=05Y!7\-F#Q^$````
M``!,8_#KH`\?`$2+/3&?``!$B?_HZ?+__TR)XDB)[DB)Q^C[\___ZZSH5/7_
M_P\?0`#S#Q[Z2(/L"(L]`I\``.B]\O__2(L5QIX``$B#Q`A(C0T3?```2(G'
M2(TUW3X``.G<]?__9F8N#Q^$``````"0\P\>^DB#[`B+/<*>``#H??+__TB)
MQ^BE____BSVOG@``Z&KR__],C04T0```13')2(T5F0\``$B)QTR)P4B--:0^
M``!(@\0(Z>/S__\/'P#S#Q[Z05154TB![``0``!(@PPD`$B![``0``!(@PPD
M`$B#["!D2(L$)2@```!(B80D&"```#'`2(GE3(VD)!`0``#H*?/__TR-#2H^
M``"Z`1```$B)[T&)P$B-#4T^``"^`0```#'`Z.3T__^Z`!```$R)YDB)[^BT
M\___13'`A<!X+HUX`4B)PTAC_^AO\O__28G`2(7`=!A(8]M,B>9(B<=(B=KH
M]O3__\8$&`!)B<!(BX0D&"```&1(,P0E*````'4/2('$("```$R)P%M=05S#
MZ.CS__\/'X0``````/,/'OKI%____P\?@`````#S#Q[Z05=!5D%505154TB!
M[``0``!(@PPD`$B![+@```!D2(L$)2@```!(B80DJ!```#'`28G\28GV2(T]
MB#T``$B-="0,Z*7W__^^+P```$R)YTB)Q>@5\___2(7`=$!,B>9(C3UH/0``
M,<#HW_C__TR)X$B+C"2H$```9$@S#"4H````#X5R`0``2('$N!```%M=05Q!
M74%>05_##Q\`3(GGZ!CR__](C34P/0``3(GW08G%Z#;S__](B<-(A<!TGH`[
M`$R--:D\```/A-4```!F#Q]$``!(A>UT$TB)WDB)[^CX\O__A<`/A)0```!(
MB=_HR/'__XG"2)B`?`/_+W46#Q]$``"#Z@%(8\*`?`/_+\8$`P!T[T&-1!4!
M/?\/```/CS?___])B=BZ`!```+X!````,<!,C;PDH````$B#[`A(C0V,/0``
M051,C0V-/```3(G_Z`3S__](C50D($R)_K\!````Z++R__]:687`=1"+1"0H
M)0#P```]`(```'1,2(TU5#P``#'_Z%[R__](B<-(A<`/A,+^__^`.P`/A3'_
M__](A>UT!H!]`"YT#DR)\[H!````Z5K___^0@'T!`'2^Z^H/'X0``````+X!
M````3(G_Z)/R__^%P'6C3(G^2(T]YSL``.A@]___3(G_Z+CQ___I=_[__^C.
M\?__9F8N#Q^$```````/'P#S#Q[Z#[8'28GXA,!T$V:02(/'`3PO#[8'3`]$
MQX3`=>],B<##9F8N#Q^$``````#S#Q[Z2(7_#X3#````58`_`$B)_0^$G@``
M`.AA\/__2(U4!?](.=5R$.F7````9I!(@^H!2#G5="6`.B]T\D@YU0^#?@``
M`$B#Z@%(.=5T#H`Z+W0@2(/J`4@YU77R@#HO=%5(C3TW.P``7>D`\?__@#HO
M=0E(@^H!2#G5<O)(*>HQP$B-2@)(@?D`$```=Q](@\(!N0`0``!(B>Y(C3TM
MFP``Z)CN__](C04AFP``7<,/'X``````2(T]=CH``%WIJ_#__T@YU76KZY(/
M'T``2(T]7CH``.F4\/__#Q]``/,/'OI5,=)(C3VU.@``2(/L0&8/;P66=P``
M9$B+!"4H````2(E$)#@QP&:)5"0P2(UL)`P/*40D$&8/;P5_=P``#RE$)"#H
M5?7__S'`2(T]>#H``.A']?__,<!(C3UR.@``Z#GU__\QP$B-/6TZ``#H*_7_
M_S'`2(T]9CH``.@=]?__,<!(C3UH.@``Z`_U__\QP$B-/0\Z``#H`?7__S'`
M2(T]6#H``.CS]/__,<!(C3U4.@``Z.7T__\QP$B-/5`Z``#HU_3__S'`2(T]
MX#D``.C)]/__,<!(B>Y(C3T[.@``Z.CS__](A<!T$4B)QDB-/1,Z```QP.@R
M]?__2(GN2(T])SH``#'`Z,'S__](B<9(A<!T#DB-/2,Z```QP.@+]?__2(GN
M2(T]'3H``#'`Z)KS__](B<9(A<!T0DB-/60Y```QP.CD]/__,<!(C34C.@``
M2(T]B#D``.C/]/__2(M$)#AD2#,$)2@```!U8$B#Q$!=PV8/'X0``````$B)
M[DB-/=(Y```QP.@_\___2(G&2(7`=!=(C3U@.0``,<#HB?3__^NC#Q^`````
M`$BX4$%27T-,14%(.40D(76+9H%\)"E./76"2(UT)"OKR.C:[O__9BX/'X0`
M`````/,/'OI(@^P89$B+!"4H````2(E$)`@QP(L%8I@``(/X_W0=2(M\)`AD
M2#,\)2@```!U1$B#Q!C##Q^$``````!(C70D!$B-/=0X```QP.B=\O__2(G"
M,<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%"Y@``.NLZ%3N__\/'T``\P\>
M^DB#[`CH<^[__XG'Z/SL__](A<!T`TB+`$B#Q`C#9F8N#Q^$```````/'T``
M\P\>^D%454B)_4B-/=DX``!32(/L$&1(BP0E*````$B)1"0(,<!(C70D!.@0
M\O__2(GN2(7`=`B`.`!(B<-U,$B-/:,X```QP.A2\___2(M$)`AD2#,$)2@`
M```/A7\```!(@\006UU!7,,/'T0``$B)Q^CX[/__2(7`==%(B>_HB^S__TB)
MWTF)Q.B`[/__28U\!`+HQNO__TB#[`A)B>B^`0```%-(Q\+_____2(G'28G$
M3(T-=#<``$B-#64X```QP.CG[?__3(GF2(T]%S@``#'`Z,;R__]86NEM____
MZ#KM__]F+@\?A```````\P\>^D%7059!54%455-,C9PD`(#__TB![``0``!(
M@PPD`$PYW'7O2('LB`$``&1(BP0E*````$B)A"1X@0``,<!(C07.-P``3(UD
M)!Q)B?U(B40D($B-!7DV``!,B>9(C3W#-@``2(E$)"A(C05(-P``2(E$)&A(
MC06=-P``2(E$)'!(C05--P``2(E$)'A(C06--P``2(F$)(````!(C06"-P``
M2(E$)$@QP$C'1"0P`````$C'A"2(`````````$C'1"10`````.B!\/__2(7`
M=`R`.`!(B<4/A0`%```QP.CY_?__2(G%2(7`#X1-!```2(GOZ"7K__](C7P`
M`>AKZO__1`^V10!(B<-%A,!T.4F)WTR--10W```/'T``3(G_3(GQ2,?"____
M_S'`O@$```!(@\4!28/'`NA_[/__1`^V10!%A,!UU4R-="1@2(T]:C8``.L8
M#Q^``````$F+?@A)@\8(2(7_#X27`0``3(GF,<#HU>___TB)Q4B%P'3=@#@`
M=-A(B<?HT/3__X7`=,Q(B>_H=.O__TF)QTB%P`^$8`$```\?A```````3(GY
MBQ%(@\$$C8+__O[^]](AT"6`@("`=.F)PL'J$*F`@```#T3"2(U1`D@/1,J)
MP@#"2(G:2(/9`TPI^8LR2(/"!(V&__[^_O?6(?`E@("`@'3IB<;![A"I@(``
M``]$QDB-<@)(#T36B<9``,9(@]H#2"G:1(VT$00$``!-8_9,B??H..G__U--
MB?A,C0W^-```2(G%2(T%\34``+X!````2,?"_____U!(C0W4-0``2(GO,<#H
M5>O__TB)[[[``0``Z+CK__]?05B#^/]U$NA[ZO__1(L(08/Y$0^%(@,``$B-
ME"20````2(GNOP$```#H.>K__XG#A<`/A+\```!)BTT`2(L]=)0``$F)Z#'`
M2(T5(#8``+X!````13'VZ$OH__](BX0D>($``&1(,P0E*`````^%]`0``$B!
MQ(B!``!,B?!;74%<05U!7D%?PP\?@`````!(BVPD($4Q]NL39@\?1```26/&
M2(MLQ"!(A>UT.X!]``!T-4B)[T&#Q@'H*?/__X7`=-U(B>_HS>G__TF)QTB%
MP`^%8?[__TECQDB+;,0@2(7M=<D/'T``13'_Z4C^__\/'X0``````(N$)*@`
M```E`/```#T`0```#X4J____1(N\)*P```#HS.G__T$YQP^%%/___XN$)*@`
M```E_P$``#W``0``#X7]_O__3(GWZ+3G__](C3U"-```3(GF28G&,<#H@.W_
M_TB)QTB%P`^$)`(``.@OZ?__28M]`$B)QNAS]?__28G$2(7`#X0'`@``3(GG
MZ!_H__^#^`-^.DACT+D%````2(T]+C0``$F-=!3\\Z8/E\*`V@"$TG4:@_@$
M#X0%`P``@^@$2)A!@'P$_R\/A/0"```QP.@9^O__A<!U%4R)YS'VZ!OH__]!
MB<2%P`^%J0$``$B--9$S``!(C3T2,P``,<#H.^[__TR-)04T``!,C2V^,@``
MZ%CG__]!5$F)Z+X!````4$C'PO____],B?<QP$R-#9LR``!(C0VO,P``Z`[I
M__]86NM+9BX/'X0``````.@[Z/__@S@1=4GH$>?__X/#`4B#[`A-B>E!5$F)
MZ$B-#84S``!,B?=32,?"_____[X!````4#'`Z,/H__](@\0@OL`!``!,B??H
M(NG__X/X_W2M2(GOZ/7F__],B?9(C3T$,@``,<#HA.W__TR)]^C<^?__Z9S]
M__\/'X``````,=M(C3W!,@``ZQ(/'T0``$ACPTB+?,1`2(7_=#A,B>8QP(/#
M`>CFZ___2(7`=.&`.`!TW$B)Q^B4Y___2(G%2(7`#X5K^___2&/#2(M\Q$!(
MA?]UR+\-````2(TM;C(``.C*Y?__0;A3````2(G#Z5[[__])BTT`2(L]<9$`
M`$F)Z#'`2(T5W3(``+X!````13'VZ$CE___I^/S__P\?`$B)Q^@H^?__2(GO
MZ"#G__])B<;IW?S__P\?A```````38ME`.GP_?__N@(```!(Q\;N____B<?H
MA.?__TB-G"1P`0``N@8```!$B>=(B=[H'.7__X"\)'`!````=0Z`O"1Q`0``
M0P^$*@$``#'2,?9$B>?H2.?__S'`Z,$<``!)B<7K$0\?0`")PDB)WDR)[^@+
M'0``N@"```!(B=Y$B>?HR^3__X7`?]]$B>=,C;PD(`$``$R-)94Q``#H4.3_
M_TR)[DR)_TR-K"1H`0``Z'T>``!(C80D0`$``$B)1"0(2(G##Q]$``!%#[8'
M2(G?3(GAO@$```!(Q\+_____,<!(@\,"28/'`>C3YO__23G===9(C06(,0``
MQH0D:`$```!0_W0D$$B-#4`Q``!)B>A,B?<QP+X!````3(T-(#```$C'PO__
M___HD^;__UE>Z=_]__]-BVT(387M#X3__/__3(GOZ-?D__](@_@##X;M_/__
M28UT!?RY!0```$B-/>0P``#SI@^7P!P`A,!-#T3EZ<K\__^`O"1R`0``00^%
MR/[__X"\)',!``!##X6Z_O__@+PD=`$``$@/A:S^__^`O"1U`0``10^%GO[_
M_[H"````2,?&QO___T2)Y^C>Y?__NBD```!(B=Y$B>?H?N/__TB-!:@P``!0
M4^DF____Z$OE__]F9BX/'X0``````/,/'OI!5T%6055!5%532(/L&(L]Z(X`
M`&1(BP0E*````$B)1"0(,<!,C6PD!.B.XO__BSW(C@``2(G#Z(#B__\/MI.X
M````3(GN2(T](R\``(B0N0```#'`Z`+I__](A<!T"8`X,0^$]`(``#'`Z!WT
M__^+/8>.``#H0N+__[D+````N@$```!(C37\+P``2(G'Z!GC__]$BS5BC@``
M2(7`#X3)````2(M`$(,]WIX```%,BV`H#XZT````,=OK,DF+=Q!(BP6]G@``
M2&/52(L\T.AYY/__08G`BP6PG@``187`#X5\````@\,".<.)ZWUS1(GWC6L!
MZ,/A__\QR4ACTTR)YDB)Q^BSX___2(7`=$9,BSA$BS7DC0``08M'#"4`!"``
M/0`$``!TE$2)]^B,X?__3(G^N0(````QTDB)Q^@*Y?__1(LULXT``$B)QNEO
M____#Q\`BP4RG@``1(LUFXT``(U0_SG:#X2``0``1(GWZ$CA__^Y`P```+H!
M````2(TU!R\``$B)Q^@?XO__2(G#2(7`=#5(BT`0BSU=C0``2(LHZ!7A__](
MC17@+@``2(G'2(GNZ"/B__](BT,02(LH]D4.0`^%S@$``(L]+(T``.CGX/__
MN0,```"Z`0```$B--<8N``!(B<?HON'__TB)PTB%P'0]3(GN2(T]/BT``#'`
MZ%7G__])B<1(A<`/A%D!``!(BT,0BSW?C```2(LHZ)?@__],B>)(B<=(B>[H
MJ>'__XL]PXP``.A^X/__N@$```!(C35)+@``2(G'Z(K@__^+/:2,``!(B<7H
M7.#__TB-%4$N``!(B>Y(B<?H:N'__XL]A(P``.@_X/__3(GN2(T]KBP``,:`
MN0`````QP.C'YO__2(D%^)P``$F)Q$B%P`^$A````+[``0``3(GGZ(?C__^-
M4`&#^@%V"8/X$0^%\@```$B+1"0(9$@S!"4H````#X79````2(/$&%M=05Q!
M74%>05_##Q\`@_@!#XYW_O__NP$```!FD$2)]X/#`>BUW___3(GF2(G'Z(K@
M__\Y'72<``!$BS7=BP``?]OI1O[__V8/'T0``$B+/5&<``#HU/3__TB)!56<
M``!)B<1(A<`/A5W___](C3WZ+0``,<#H(^+__P\?`(!X`0`/A`G]___I_?S_
M_Y!(BP41G```BSV#BP``3(L@2(M#$$B+*.@TW___3(GF2(GOZ&GK___IF_[_
M_XL]7HL``.@9W___2(GN2(G'Z'[A___I%_[__^B$X?__B<%(BP7#FP``3(GB
M2(T]J2T``$B+,#'`Z*?A__\/'X``````\P\>^E5(B?U32(/L".B^[___#[80
M2(G#A-)T%@\?0`!(@\`!@/HO#[802`]$V(32=>XQP.A7\O__2(7M="2%P'0@
M@'T``'0:N00```!(C3T:+```2(G>\Z8/E\`<`(3`=`=(@\0(6UW#2(/$"$B)
M[UM=Z;GH__]F#Q^$``````!!5TR-3SA!5D%505154TB![)@"``!D2(L$)2@`
M``!(B80DB`(``#'`2(GB3(V4)(````!)B=!F+@\?A```````08L!28LQ28/`
M$$F#P0@/R(G`2(GQ28E`\$B)\$C!Z2!(P>@H2,'N."4`_P``2`GP2(G.2,'A
M"$C!YAB!X0``_P")]D@)\$@)R$F)0/A-.=!UKDB-L@`"```/'X``````2(M"
M:$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@_TB)0GA(.?)UU4R+!TR+
M3Q!(BU\@3(M7&$R)P$R)PDB+="0(3(MT)!A(P>H;2,'@!4@)T`,$)$F-K#*9
M>8):C908F7F"6DR)R$R)PTPQT$@C1PA(P>,>3#'01(TD`DB+5PA(BT<(3(GF
M2,'B'DC!Z`)("=!,B<I(P>X;B<%(,<I,(<),,<I(`>I,B>5(P>4%2`GU2`'5
M3(G"2,'J`D&)[4@)TTB+5"002#'808G;3"'@28V4$9EY@EI(,<A*C8PQF7F"
M6DB--!!(B>I(P>T;2+C@____'P```$C!X@6#Y1]((<)(">I(`?),B>9)P>P"
M2,'F'HG53`GF2#'S08GT3"'K3#';2`'+2(G12,'J&TC!X06#XA]((<%("<I,
MB>E)P>T"2,'A'D@!VDP)Z4R+;"0@B=-(,<Y!B<Y((>Y/C9PKF7F"6DPQYDP!
MWDF)TTC!ZAM)P>,%@^(?22'#20G32(M4)"A)`?-(B>Y(P>T"2,'F'DF-E!29
M>8):18G=2`GN2#'QB?5((=E,,?%(`<I,B=E(P>$%2"'!2<'K&T&#XQ],"=E,
MBUPD,$@!T4B)VDC!ZP)(P>(>3XV<'IEY@EI!B<Q("=I(,=:)TTPA[D@Q[DD!
M\TB)SDC!Z1M(P>8%@^$?2"'&2`G.2(M,)#A,`=Y-B>M)P>T"2<'C'DB-C`V9
M>8):08GV30GK3#':18G=3"'B2#':2`'12(GR2,'N&TC!X@6#YA]((<)("?)(
MBW0D0$@!RDR)X4C!X1Y)P>P"2(VT,YEY@EJ)U4P)X4DQRT&)S$TA\TTQZTP!
MWDF)TTC!ZAM)P>,%@^(?22'#20G32(M4)$A)`?-,B?9)P>X"2,'F'DF-E!69
M>8):1(G;3`GV2#'Q08GV2"'I3#'A2`'*3(G92<'K&TC!X05!@^,?2"'!3`G9
M3(M<)%!(`=%(B>I(P>T"2,'B'D^-G!R9>8):08G-2`GJ2#'6B=5((=Y,,?9)
M`?-(B<Y(P>8%2,'I&T@AQH/A'T@)SDB+3"183`'>28G;2,'K`DG!XQY)C8P.
MF7F"6D&)]$D)VTPQVD2)VTPAZD@QZD@!T4B)\DC![AM(P>(%@^8?2"'"2`GR
M2(MT)&!(`<I,B>E)P>T"2,'A'DB-M#69>8):08G63`GI23'+08G-32'C23';
M3`'>28G32,'J&TG!XP6#XA])(<-)"=-(BU0D:$D!\TR)YDC!YAY)P>P"2(V4
M$YEY@EI$B=U,">9(,?%!B?1,(?%,,>E(`<I,B=E)P>L;2,'A!4&#XQ]((<%,
M"=E,BUPD<$@!T4R)\DG![@)(P>(>3XV<'9EY@EJ)RTP)\D@QUD&)UD@A[DPQ
MYDD!\TB)SDC!Z1M(P>8%@^$?2"'&2`G.2(M,)'A,`=Y)B>M(P>T"2<'C'DF-
MC`R9>8):08GU20GK3#':1(G=2"':3#'R2`'12(GR2,'N&TC!X@6#YA]((<)(
M"?)(B[0D@````$@!RDB)V4C!ZP)(P>$>28VT-IEY@EI!B=1("=E),<N)RTTA
MZTDQZTP!WDF)TTC!ZAM)P>,%@^(?22'#20G32(N4)(@```!)`?-,B>Y)P>T"
M2,'F'DB-E!69>8):18G>3`GN2#'Q08GU3"'A2#'92`'*3(G92<'K&TC!X05!
M@^,?2"'!3`G92`'13(GB2<'L`DC!XAZ)S4P)XDR+I"20````2#'608G33"'V
M2HV<(YEY@EI,,>Y(`=Y(B<M(P>D;2,'C!8/A'T@APT@)V4R)\TG![@)(P>,>
MB<E,"?-(`<Y(BXPDF````$@QVD&)]$@AZDF-C`V9>8):38GE3#':2<'M&T@!
MRDR)X4C!X05,">F)R4@!RDB)Z4C![0)(P>$>08G52`GI2(G=B=M(,<TQ[DB+
MK"2@````38V<*Z'KV6Y,B>U)`?-,B>Y(P>8%2,'M&T@#G"2H````2`GNB?9,
M`=Y-B>-)P>P"2<'C'HGU30GC28G,B<E(`XPDL````$TQW$0QXDR-I!.AZ]EN
M2(GJ2(GK2,'K&TC!X@5("=J)TDF-'!1,B>I)P>T"2,'B'D&)W$P)ZDV)W46)
MVTP#G"2X````23'51#'N38GE2(VT,:'KV6Y,B>%)P>T;2,'A!4P)Z8G)2`'Q
M2(GN2,'M`DC!YAY!B<U(">Y(B=6)TD@Q]3'K3(GM28V<&Z'KV6Y-B>M(P>T;
M2<'C!4D)ZT6)VTD!VTR)XTC!XQY)P>P"1(G=2`.4),````!,">-)B?2)]D@#
MM"3(````23'<1#'A28GL2(V,"J'KV6Y(B>I)P>P;2,'B!4P)XHG22`'*3(GI
M2<'M`DC!X1Y!B=1,">E)B=V)VT@#G"30````23'-13'K38GE3HV<'J'KV6Y,
MB>9)P>T;2,'F!4P)[HGV3`'>28GK2,'M`DG!XQY!B?5)">M(B<V)R4PQW3'J
M2(VL$Z'KV6Y,B>I,B>M(P>L;2,'B!4@)VHG22(U<%0!,B>))P>P"2,'B'HG=
M3`GB38G<2`.,)-@```!%B=M),=1,`YPDX````$0QYDF)[$B-M#&AZ]EN2(GI
M2<'L&TC!X05,">&)R4@!\4R)[DG![0)(P>8>08G,3`GN28G5B=)(`Y0DZ```
M`$DQ]40QZTV)Y4F-G!NAZ]EN38GC2<'M&TG!XP5-">M%B=M)`=M(B>M(P>T"
M2,'C'D6)W4@)ZTB)]8GV2`.T)/````!(,=TQZ4R)[4B-C`JAZ]EN3(GJ2,'M
M&TC!X@5(">J)TD@!RDR)X4G![`)(P>$>B=5,">%)B=R)VTDQS$4QXTF)[$@#
MG"3X````3HV<'J'KV6Y(B>Y)P>P;2,'F!4P)YHGV3`'>38GK2<'M`DG!XQY!
MB?1-">M)B<V)R4@#C"0``0``33'=1#'J3(VL$Z'KV6Y,B>),B>-(P>L;2,'B
M!4@)VHG228U<%0!(B>I(P>T"2,'B'D&)W4@)ZDR)W46)VTP#G"0(`0``2#'5
M,>Y,B>U(C;0QH>O9;DR)Z4C![1M(P>$%2`GIB<E(`?%,B>9)P>P"2,'F'HG-
M3`GF28G4B=)),?1$,>-)B>Q)C9P;H>O9;DF)ZTG![!M)P>,%30GC2`.4)!`!
M``!%B=M)`=M,B>M)P>T"2,'C'D6)W$P)ZTF)]8GV2`.T)!@!``!),=U$,>E-
MB>5(C8P*H>O9;DR)XDG![1M(P>(%3`GJB=)(`<I(B>E(P>T"2,'A'D&)U4@)
MZ4B)W8G;2`.<)"`!``!(,<U!,>M,B>U.C9P>H>O9;DR)[DC![1M(P>8%2`GN
MB?9,`=Y-B>-)P>P"2<'C'HGU30GC28G,B<E-,=Q$,>),C:03H>O9;DB)ZDB)
MZTC!ZQM(P>(%2`G:B=))C1P43(GJ2,'B'DG![0)!B=Q(`XPD*`$``$P)ZDV)
MW46)VTP#G"0P`0``23'51#'N38GE2(VT,:'KV6Y,B>%)P>T;2,'A!4P)Z8G)
M2`'Q2(GN2,'M`DC!YAY!B<](">Y(B=5-B?V)TD@Q]4G!Y05(`Y0D.`$``#'K
M28V<&Z'KV6Y-B?M)P>L;30GK3HTL&TR)XTG![`))B?-(P>,>1(GMB?9,">-)
M,=M!B=Y$,=E-B>M)P>T;2<'C!4B-E`JAZ]EN08/E'TR)^4C!X1Y)(<-)P>\"
M30GK28G=20'33`GYNMR\&X]!B<])"<U%B=Q,(?M)(>U)"=U(BYPD0`$``$@!
MTT@!WDD!]4R)WDG!ZQM(P>8%08/C'T@AQDP)WDP![DF)[4C![0))P>4>B?-)
M">U,">E-B>M$B>U-(?M,(>%,"=E,BYPD2`$``$D!TTT!\TV)YDG![`))`<M(
MB?%(P>X;2,'A!8/F'TG!YAY((<%("?%,B>Y,`=E-">9%B?1,"?9!B<M((=Y-
M(>5)"?5(B[0D4`$``$@!UDP!_DF)WTC!ZP))`?5(B<Y)P><>2,'F!4C!Z1M)
M"=]((<:#X1]-"?Y$B?M("<Y,B?E-(=Y,(>%,`>Y)"<Y(BXPD6`$``$&)]4@!
MT4@!Z4D!SDB)\4C![AM(P>$%@^8?2"'!2`GQ3(G^3`'Q38G>2<'K`DG!YAZ)
MS4T)WD6)\TP)]DPA[DTAWTD)]TB+M"1@`0``2`'63`'F20'W2(G.2,'I&TC!
MY@6#X1]((<9("<Y,`?Y-B>])P>T"2<'G'D&)]$T)[TT)_DR)^46)_4PAV4DA
M[DD)SDB+C"1H`0``2`'12`'920'.2(GQ2,'N&TC!X06#YA]((<%("?%,B?Y,
M`?%)B>Y(P>T"2<'F'HG+20GN1(GU3`GV3"'F22'O20GW2(NT)'`!``!(`=9,
M`=Y)`?=(B<Y(P>D;2,'F!8/A'T@AQD@)SDP!_DV)YTG![`))P><>08GS30GG
M30G^3(GY18G\2"'I22'>20G.2(N,)'@!``!(`=%,`>E)B=U(P>L"20'.2(GQ
M2,'N&TC!X06#YA])P>4>2"'!2`GQ3(G^3`'Q20G=1(GK3`GN08G.3"'>22'?
M20GW2(NT)(`!``!(`=9(`>Y)`?=(B<Y(P>D;2,'F!8/A'T@AQD@)SDP!_DV)
MWTG!ZP))P><>B?5-"=]-"?U,B?E%B?M((=E-(?5)"<U(BXPDB`$``$@!T4P!
MX4D!S4B)\4C![AM(P>$%@^8?2"'!2`GQ3(G^3`'I38GU2<'N`DG!Y1Y!B<Q-
M"?5%B>Y,">Y((>Y-(?=)"?=(B[0DD`$``$@!UD@!WDD!]TB)SDC!Z1M(P>8%
M@^$?2"'&2`G.3`'^28GO2,'M`DG!YQZ)\TD)[TT)_4R)^42)_4PA\4TAY4D)
MS4B+C"28`0``2`'13`'920'-2(GQ2,'N&TC!X06#YA]((<%("?%,B?Y,`>E-
MB>5)P>P"2<'E'D&)RTT)Y46)[$P)[D@AWDTAYTD)]TB+M"2@`0``2`'63`'V
M20'W2(G.2,'I&TC!Y@6#X1]((<9("<Y,`?Y)B=](P>L"2<'G'D&)]DD)WTT)
M_4R)^42)^TPAX4TAW4D)S4B+C"2H`0``2`'12`'I3(G=2<'K`DD!S4B)\4C!
M[AM(P>$%@^8?2,'E'D@AP4@)\4R)_DP!Z4P)W4&)ZT@)[D&)S4PA]DTAWTD)
M]TB+M"2P`0``2`'63`'F20'W2(G.2,'I&TC!Y@6#X1]((<9("<Y,`?Y-B?=)
MP>X"2<'G'D&)]$T)]TP)_4R)^46)_DPAV4PA[4@)S4B+C"2X`0``2`'12`'9
M3(GK2<'M`D@!S4B)\4C![AM(P>$%@^8?2,'C'D@AP4@)\4R)_D@!Z4P)ZT&)
MW4@)WHG-3"'F32'O20GW2(NT),`!``!(`=9,`=Y-B>-)P>P"20'W2(G.2<'C
M'DC!Y@5(P>D;30GC2"'&@^$?3`G;18G<2`G.3(G92"'K3"'I3`'^2`G+2(N,
M),@!``!!B?=(`=%,`?%-B=Y(`<M(B?%(P>X;2,'A!8/F'T@AP4@)\4@!V4B)
MZTC![0)(P>,>B<Y("=V)ZTD)[DTA_DDAVTT)\TR+M"30`0``20'62`.4)-@!
M``!-`?5,`>)-`=U)B<M(P>D;2<'C!8/A'TDAPTP)V8G)3`'I38G]2<'O`DG!
MY1Y!B<M-">]-B=Q,"?U-B?Y)P>P;18G]22'>2"'U3`GU3(NT).`!``!(`=5,
MB=I(P>(%3`GBB=)(`=5(B?)(P>X"2,'B'D&)[$@)UKK6P6+*23'W1#'Y20'6
M3`'S38GF2`'+3(GA2<'N&TC!X05,"?&)R4@!RTR)V4G!ZP)(P>$>08G>20G+
M2(GQB?9,,=DQS4B+C"3H`0``2`'13`'I38GU2`'-3(GQ2<'M&TC!X05,">F)
MR4@!S4R)X4G![`)(P>$>08GM20G,2(N,)/`!``!(`=%(`?%,B=Y%B=M,,>8Q
MWDR)ZT@!SDR)Z4C!ZQM(P>$%2`G9B<E(`<Y,B?%(P>$>2<'N`HGS20G.2(N,
M)/@!``!(`=%,`=E-B>-%B>1-,?-$,=U)B=M(`<U(B=E)P>L;2,'A!4P)V4R+
MG"0``@``B<E(`<U,B>E)`=-)P>T"2,'A'DT!XTV)]$&)[TP)Z46)]DDQS$0Q
MYDV)_$D!\TR)_DG![!M(P>8%3`GF08GT2(G>2,'K`DC!YAY-`=Q)B<N)R4@)
M\TB+M"0(`@``18GE23';2`'61#'=38GK3`'V2`'U3(GN2,'F!4G!ZQM,"=Y-
MB?M)P>\"B?9)P>,>2`'U2(NT)!`"``!-"?M!B>Y(`=9(`?%(B=Z)VTPQWD$Q
M]$R)]DD!S$R)\4C![AM(P>$%2`GQB<E)`<Q,B>E)P>T"2,'A'D6)YTD)S4B+
MC"08`@``3(G^2,'N&T@!T4@!V4R)VT6)VTPQZS'K2`'+3(GY2,'A!4@)\4R)
M]DG![@*)R4C!YAY(`<M(BXPD(`(``$P)]HG=2`'13`'938GK18GM23'S13'<
M28GK20',2(GI2<'K&TC!X05,"=E)B?.)]HG)20',3(GY2<'O`DC!X1Y%B>9)
M"<](BXPD*`(``$TQ^T@!T40QVTV)\TP!Z4G!ZQM(`<M,B?%(P>$%3`G93(N<
M)#`"``")R4@!RTB)Z4C![0))`=-(P>$>08G=3`'>2`GI3(G]38GK18G_2#'-
M2<'K&T0QY4@!]4R)[DC!Y@5,"=Y)B<N)R8GV2`'U3(GV2,'F'DG![@)!B>Q)
M"?9(B[0D.`(``$TQ\T@!UD0QVTV)XTP!_DG!ZQM(`?-,B>9(P>8%3`G>38GK
M2<'M`HGV2<'C'D@!\TB+M"1``@``30GK08G?2`'62`'Q3(GV18GV3#'>,?5,
MB?Y(`<U,B?E(P>X;2,'A!4@)\4R)WD6)VXG)2`'-3(GA2<'L`DC!X1Y!B>U)
M"<Q(BXPD2`(``$PQYD@!T3'S3(GN3`'Q2`'+3(GI2,'A!4C![AM("?%,B?Y)
MP>\"B<E(P>8>2`'+2(N,)%`"``!,"?Y!B=Y(`=%,`=E-B>-%B>1),?-!,>M,
MB?5)`<M,B?%(P>T;2,'A!4@)Z8G)20'+3(GI2<'M`DC!X1Y$B=U)"<U(BXPD
M6`(``$@!T4P!X4F)](GV33'L1#'C28GL2`'+2(GI2<'L&TC!X05,">&)R4@!
MRTR)\4G![@)(P>$>08G<3`GQ3(NT)&`"``!)`=9,`?9-B>Y%B>U),<Y%,?--
MB>9,`=Y-B>-)P>X;2<'C!4T)\TF)[DC![0))P>8>18G;3`GU3(NT)&@"``!,
M`=Y!B?-)`=9-`?5)B<Z)R4DQ[D0Q\TV)WDP!ZTV)W4G![AM)P>4%30GU38GF
M2<'L`DG!YAY%B>U-"?1,B[0D<`(``$P!ZT&)W4D!UDP!\4F)[HGM33'F1#'V
M38GN2`'.3(GI2<'N&TC!X05,"?%(`?%,B=Y(P>8>2<'K`D@#E"1X`@``20GS
M3(GF3`'"1`-G($PQWD@!ZD4!VDR)9R`Q\TB)SDR)5QA(P>8%2`':2"'P2(G.
M`T\(2,'N&TB)3PB#YA]("?`!T$B)!TR)Z$G![0)(P>`>20G%10'I3(E/$$B+
MA"2(`@``9$@S!"4H````=1)(@<28`@``6UU!7$%=05Y!7\/H',K__V9F+@\?
MA```````D/,/'OI(@^P(OX````#H/LC__[J)J\WON?[<NIB^\.'2PTC'``$C
M16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,`````#'0'@`````
M2(/$",,/'X0``````/,/'OI!5TACPD%628G&055!5$F)_%5(C6\X4TB)\TB#
M[`A(BW<H2(M7,(T,QD@Y\4B)3RA(@](`2,'H'4@!T$B)1S!(8T=XA<`/A?D`
M``!!@_X_#XXW`0``08/N0$6)]T'![P9%B?U)@\4!2<'E!DD!W68/'T0``/,/
M;P-,B>=(@\-`#Q%%`/,/;TO0#Q%-$/,/;U/@#Q%5(/,/;UOP#Q%=,.@IZ/__
M3#GK=<Q!P><&12G^26/&2(/X"')D28M5`$F)5"0X28M4!?A(B50%^$B-50A(
M@^+X2"G522GM2`'%2(/E^$B#_0AR&$B#Y?@QP$F+3`4`2(D,`DB#P`A(.>AR
M[D6)="1X2(/$"%M=05Q!74%>05_#9BX/'X0``````*@$=71(A<!TV4$/ME4`
M08A4)#BH`G3+00^W5`7^9HE4!?[KO@\?0`!!O4````!(C7P%`$B)WD$IQ44Y
M[D4/3NY-8_U,B?KH)<G__T&+1"1X1`'H08E$)'B#^$!UBDR)YT4I[DP!^^A%
MY___Z;_^__])B=WI&____T&+50!!B50D.$&+5`7\B50%_.E3____D/,/'OI!
M5DR-=CA!54%454B)]5-(BT8H2(G[1(MF*$2+;C!(P>@#@^`_00_,00_-C4@!
M2)C&1`8X@$ACP4P!\(/Y.`^.*`$``+I`````*<J)T70/,=*)UH/"`<8$,``Y
MRG+S2(GOZ+;F__]F#^_`#Q%%.$G'1C``````00\11A!!#Q%&($2);7!(B>]$
MB65TZ(SF__](BT4`2(GO2,'H&(@#2(M%`$C!Z!"(0P%(BT4`2,'H"(A#`DB+
M10"(0P-(BT4(2,'H&(A#!$B+10A(P>@0B$,%2(M%"$C!Z`B(0P9(BT4(B$,'
M2(M%$$C!Z!B(0PA(BT402,'H$(A#"4B+11!(P>@(B$,*2(M%$(A#"TB+11A(
MP>@8B$,,2(M%&$C!Z!"(0PU(BT482,'H"(A##DB+11B(0P](BT4@2,'H&(A#
M$$B+12!(P>@0B$,12(M%($C!Z`B(0Q)(BT4@B$,36UU!7$%=05[I=<7__P\?
M1```NC@````Q_RG*@_H(<D*)T4C'``````!(QT0(^`````!(C4@(2(/A^$@I
MR`'"@^+X@_H(#X+;_O__@^+X,<")QH/`"$B)/#$YT'+SZ<3^___VP@1U(X72
M#X2W_O__Q@``]L("#X2K_O__,<EFB4P0_NF?_O__#Q\`QP``````QT00_```
M``#IB?[__P\?1```\P\>^D%73(T]2VL``$%628G6055)B?5!5$&)_%5(C2T\
M:P``4TPI_4B#[`CH;[___TC!_0-T'S';#Q^``````$R)\DR)[D2)YT'_%-](
M@\,!2#G==>I(@\0(6UU!7$%=05Y!7\-F9BX/'X0``````/,/'OK#9BX/'X0`
M`````)#S#Q[Z2(L-'6\``.F`P___\P\>^DB#[`A(@\0(PP``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`N+@`E<R\E<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R
M.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),
M3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$
M14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)9
M7U!!5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E
M,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S
M)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;`!005(Z
M.E!A8VME<CHZ5D524TE/3@`Q+C`U,``M90`M+0`E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``````
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#
M+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)0R`]
M(")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/
M4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P
M87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A
M;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R
M;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I('L*
M)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@)&-H
M=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*?2!E
M;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*=VAI
M;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O<RP@
M,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%2
M7TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)
M0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?
M<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\(#`[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B
M=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES
M=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H
M56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE
M(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B
M)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I
M;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M(#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U
M9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT[
M"GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM
M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L
M92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D9F@@
M)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC<F-]
M+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N
M86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D
M92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H
M;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@
M>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)3
M1%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I
M<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E
M<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@
M("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO
M9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II
M<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@
M>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O
M;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A
M;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L
M("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D
M<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P
M,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z
M.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O
M<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@
M/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@/2`B
M4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD;6%G
M:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M
M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD
M+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S*2![
M"FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*
M:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I
M;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=
M*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*
M96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM
M>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H
M4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE
M+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,12P@
M)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN
M;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,
M12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI
M.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C
M;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P
M.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T
M*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P96XH
M;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD
M:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#
M*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I
M.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(
M86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I
M>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I
M8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7
M:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![
M(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U
M:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E
M(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q
M=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE
M9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T
M:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U0
M1$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE
M>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D
M<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,
M;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M
M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-
M17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@
M<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]
M<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@
M*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P
M<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D
M8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU
M."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<[
M"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*
M?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM>2`D
M9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\?"`D
M;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD9&EG
M97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W
M-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE
M('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L
M;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA
M;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@
M)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP
M;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*
M8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@
M)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK
M*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P
M<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@
M)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D
M,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R
M;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@
M)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF
M;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O
M+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!]
M(&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N
M9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO
M)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!P97)L>'-I+F,`
M``````````````````!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(`$;`SL,`0``(````*!R__]``0``4';__V@!``!@=O__@`$```!Z__\,!@``
M$'S__R@!````??__F`$``-!]___D`0``8'[__Q`"``"P@/__7`(``!""__^@
M`@``H(+__\0"``"0@___#`,``-"#__\D`P``((3__SP#````A?__>`,``!"%
M__^,`P``((?___`#``!0A___!`0``#"(__\T!```$(K__U@$``"0BO__=`0`
M`,"*__^,!```L(O__\P$``"@D___C`4``("7___8!0```)C__S@&``#0KO__
MB`8``#"O__^@!@``X+#__^P&``#@LO__,`<``%"S__]X!P``8+/__Y`'````
M````%``````````!>E(``7@0`1L,!PB0`0``%````!P```#@>O__+P````!$
M!Q``````)````#0```!8<?__L`,````.$$8.&$H/"W<(@``_&CHJ,R0B````
M`!0```!<````X'3__Q```````````````!0```!T````V'3__Z`#````````
M`````$@```",````8'O__\T`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&
M!D$..(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P`H````V````.1[
M__^$`````$$.$(8"00X8@P-'#C`"<PH.&$$.$$$."$$+`$@````$`0``2'S_
M_TD"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`Q<!"@XX
M00XP00XH0@X@0@X80@X00@X(2PM`````4`$``$Q^__]<`0```$(.$(X"0@X8
MC0-"#B",!$$.*(8%00XP@P9'#M`!?@H.,$$.*$$.($(.&$(.$$(."$L+`"``
M``"4`0``:'___XL`````00X0A@)2#K`!`G$*#A!!#@A!"T0```"X`0``U'__
M_^P`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D<.L"!)#L`@`I0*#C!!
M#BA"#B!"#AA"#A!"#@A*"Q0``````@``?(#__S0`````2`X05@X(`!0````8
M`@``I(#__TT`````2`X0`D`."#@````P`@``W(#__]@`````1@X0C`)!#AB&
M`T$.((,$1PZ@($P.H$!)#L!``J<*#B!$#AA!#A!"#@A!"Q````!L`@``@('_
M_PD`````````8````(`"``!\@?__`@(```!&#A"/`D(.&(X#0@X@C01"#BB,
M!4$.,(8&00XX@P='#K@@3`[P(0)Q"@XX00XP00XH0@X@0@X80@X00@X(1`L"
MI`[X(4D.@")B#O@A00[P(0```!````#D`@``*(/__R4`````````+````/@"
M``!$@___W`````!.#A"&`@)="L8."$4+`D`*#@A("T@*Q@X(10M+#@C&(```
M`"@#``#T@___U@$```!%#A"&`DT.4`-C`0H.$$$."$H+&````$P#``"PA?__
M?`````!(#B!O"@X(20L``!0```!H`P``%(;__R$`````2`X06`X(`#P```"`
M`P``+(;__^8`````1@X0C`)!#AB&`TL.((,$1`XP`E`*#B!!#AA!#A!"#@A&
M"VX..$D.0'0..$$.,`"\````P`,``-R&___E!P```$8.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T@,"[B``E$-!T<.P(,"`PL"#LB#`F$.T(,"7P[(
M@P)"#L"#`@)X"@XX1`XP00XH0@X@0@X80@X00@X(2`L#@@$.R(,"20[0@P)@
M#LB#`D$.P(,"8@[(@P)%#M"#`DX.V(,"30[@@P)+#L"#`@,!`@[(@P)$#M"#
M`F@.R(,"00[`@P("JPH.R(,"00[0@P)%"P!(````@`0```R.___9`P```$8.
M$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T0.4`/0`@H..$$.,$$.*$(.
M($(.&$(.$$(."$0+,````,P$``"@D?__=P````!%#A"&`D0.&(,#1`X@`ED*
M#AA!#A!!#@A!"T0.&$0.$$$.""@`````!0``['/__PP"````1@X0C`)!#AB&
M`T0.4`.G`0H.&$0.$$(."$$+3````"P%``#`D?__Q!8```!"#A"/`D8.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`Y\6"@XX00XP00XH0@X@0@X80@X0
M0@X(00L````4````?`4``$"H__]8`````$@.$`)/#@A(````E`4``(BH__^O
M`0```$8.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+I"@XX00XP
M00XH0@X@0@X80@X00@X(2PL`0````.`%``#LJ?__^P$```!&#A".`D8.&(T#
M0@X@C`1!#BB&!40.,(,&`TP!"@XH00X@0@X80@X00@X(2@L```````!$````
M)`8``*BK__]E`````$8.$(\"20X8C@-%#B"-!$4.*(P%1`XPA@9(#CB#!T<.
M0&X..$$.,$$.*$(.($(.&$(.$$(."``4````;`8``-"K__\%````````````
M```0````A`8``,BK__\0````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````!P*@``
M`````#`J`````````0`````````!``````````$`````````O`$````````!
M``````````L"````````#```````````(`````````T`````````\&``````
M```9`````````+C+````````&P`````````(`````````!H`````````P,L`
M```````<``````````@`````````]?[_;P````"@`P````````4`````````
M``X````````&`````````*`$````````"@````````#+!`````````L`````
M````&``````````5`````````````````````P````````#8S0````````(`
M````````<`4````````4``````````<`````````%P````````"8%0``````
M``<`````````&!0````````(`````````(`!````````"0`````````8````
M`````!X`````````"`````````#[__]O``````$```@`````_O__;P````"8
M$P```````/___V\``````@````````#P__]O`````,P2````````^?__;P``
M```$````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MR,L`````````````````````````````,"````````!`(````````%`@````
M````8"````````!P(````````(`@````````D"````````"@(````````+`@
M````````P"````````#0(````````.`@````````\"``````````(0``````
M`!`A````````("$````````P(0```````$`A````````4"$```````!@(0``
M`````'`A````````@"$```````"0(0```````*`A````````L"$```````#`
M(0```````-`A````````X"$```````#P(0`````````B````````$"(`````
M```@(@```````#`B````````0"(```````!0(@```````&`B````````<"(`
M``````"`(@```````)`B````````H"(```````"P(@```````,`B````````
MT"(```````#@(@```````/`B`````````",````````0(P```````"`C````
M````,",```````!`(P```````%`C````````8",```````!P(P```````(`C
M````````D",```````"@(P```````+`C````````P",`````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T````````/____\`````X'(```````!'
M0T,Z("A58G5N='4@.2XS+C`M,3-U8G5N='4Q*2`Y+C,N,```+G-H<W1R=&%B
M`"YI;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+F=N=2YB=6EL9"UI
M9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N
M=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`
M+FEN:70`+G!L="YG;W0`+G!L="YS96,`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A
M>0`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@`````````8`P```````!@#````````'```````
M``````````````$````````````````````3````!P````(`````````.`,`
M```````X`P```````"`````````````````````(````````````````````
M)@````<````"`````````%@#````````6`,````````D````````````````
M````!````````````````````#D````'`````@````````!\`P```````'P#
M````````(`````````````````````0```````````````````!'````]O__
M;P(`````````H`,```````"@`P```````/P`````````!@`````````(````
M````````````````40````L````"`````````*`$````````H`0```````!@
M"0````````<````!````"``````````8`````````%D````#`````@``````
M````#@`````````.````````RP0```````````````````$`````````````
M``````!A````____;P(`````````S!(```````#,$@```````,@`````````
M!@`````````"``````````(`````````;@```/[__V\"`````````)@3````
M````F!,```````"```````````<````"````"````````````````````'T`
M```$`````@`````````8%````````!@4````````@`$````````&````````
M``@`````````&`````````"'````!````$(`````````F!4```````"8%0``
M`````'`%````````!@```!@````(`````````!@`````````D0````$````&
M```````````@`````````"`````````;````````````````````!```````
M`````````````(P````!````!@`````````@(````````"`@````````L`,`
M`````````````````!``````````$`````````"7`````0````8`````````
MT",```````#0(P```````!`````````````````````0`````````!``````
M````H`````$````&`````````.`C````````X",```````"@`P``````````
M````````$``````````0`````````*D````!````!@````````"`)P``````
M`(`G````````<#D``````````````````!````````````````````"O````
M`0````8`````````\&````````#P8`````````T````````````````````$
M````````````````````M0````$````"``````````!P`````````'``````
M``"`/0``````````````````$````````````````````+T````!`````@``
M``````"`K0```````("M````````#`$```````````````````0`````````
M``````````#+`````0````(`````````D*X```````"0K@```````)@&````
M```````````````(````````````````````U0````X````#`````````+C+
M````````N+L````````(````````````````````"``````````(````````
M`.$````/`````P````````#`RP```````,"[````````"```````````````
M``````@`````````"`````````#M````!@````,`````````R,L```````#(
MNP```````!`"````````!P`````````(`````````!``````````FP````$`
M```#`````````-C-````````V+T````````H`@``````````````````"```
M```````(`````````/8````!`````P``````````T`````````#`````````
M(`````````````````````@```````````````````#\````"`````,`````
M````(-`````````@P````````*@0```````````````````@````````````
M`````````0$```$````P````````````````````(,`````````D````````
M`````````````0`````````!``````````$````#````````````````````
L`````$3`````````"@$```````````````````$`````````````````````
